# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/serverless/triggers/v1/trigger.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.logging.v1 import log_entry_pb2 as yandex_dot_cloud_dot_logging_dot_v1_dot_log__entry__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/serverless/triggers/v1/trigger.proto',
  package='yandex.cloud.serverless.triggers.v1',
  syntax='proto3',
  serialized_options=b'\n\'yandex.cloud.api.serverless.triggers.v1ZPgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/triggers/v1;triggers',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n1yandex/cloud/serverless/triggers/v1/trigger.proto\x12#yandex.cloud.serverless.triggers.v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\'yandex/cloud/logging/v1/log_entry.proto\x1a\x1dyandex/cloud/validation.proto\"\x85%\n\x07Trigger\x12\n\n\x02id\x18\x01 \x01(\t\x12\x1f\n\tfolder_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x04name\x18\x04 \x01(\tB\x08\x8a\xc8\x31\x04\x33-63\x12\x1e\n\x0b\x64\x65scription\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05\x30-256\x12H\n\x06labels\x18\x06 \x03(\x0b\x32\x38.yandex.cloud.serverless.triggers.v1.Trigger.LabelsEntry\x12\x45\n\x04rule\x18\x08 \x01(\x0b\x32\x31.yandex.cloud.serverless.triggers.v1.Trigger.RuleB\x04\xe8\xc7\x31\x01\x12\x43\n\x06status\x18\t \x01(\x0e\x32\x33.yandex.cloud.serverless.triggers.v1.Trigger.Status\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\xf6\x06\n\x04Rule\x12\x43\n\x05timer\x18\x02 \x01(\x0b\x32\x32.yandex.cloud.serverless.triggers.v1.Trigger.TimerH\x00\x12R\n\rmessage_queue\x18\x03 \x01(\x0b\x32\x39.yandex.cloud.serverless.triggers.v1.Trigger.MessageQueueH\x00\x12N\n\x0biot_message\x18\x04 \x01(\x0b\x32\x37.yandex.cloud.serverless.triggers.v1.Trigger.IoTMessageH\x00\x12[\n\x12iot_broker_message\x18\x0e \x01(\x0b\x32=.yandex.cloud.serverless.triggers.v1.Trigger.IoTBrokerMessageH\x00\x12T\n\x0eobject_storage\x18\x05 \x01(\x0b\x32:.yandex.cloud.serverless.triggers.v1.Trigger.ObjectStorageH\x00\x12\\\n\x12\x63ontainer_registry\x18\x06 \x01(\x0b\x32>.yandex.cloud.serverless.triggers.v1.Trigger.ContainerRegistryH\x00\x12L\n\ncloud_logs\x18\t \x01(\x0b\x32\x36.yandex.cloud.serverless.triggers.v1.Trigger.CloudLogsH\x00\x12G\n\x07logging\x18\n \x01(\x0b\x32\x34.yandex.cloud.serverless.triggers.v1.Trigger.LoggingH\x00\x12L\n\x0e\x62illing_budget\x18\x0b \x01(\x0b\x32\x32.yandex.cloud.serverless.triggers.v1.BillingBudgetH\x00\x12\x46\n\x0b\x64\x61ta_stream\x18\x0c \x01(\x0b\x32/.yandex.cloud.serverless.triggers.v1.DataStreamH\x00\x12\x39\n\x04mail\x18\r \x01(\x0b\x32).yandex.cloud.serverless.triggers.v1.MailH\x00\x42\x0c\n\x04rule\x12\x04\xc0\xc1\x31\x01\x1a\xdd\x02\n\x05Timer\x12&\n\x0f\x63ron_expression\x18\x01 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=100\x12R\n\x0finvoke_function\x18\x65 \x01(\x0b\x32\x37.yandex.cloud.serverless.triggers.v1.InvokeFunctionOnceH\x00\x12\x62\n\x1ainvoke_function_with_retry\x18g \x01(\x0b\x32<.yandex.cloud.serverless.triggers.v1.InvokeFunctionWithRetryH\x00\x12\x64\n\x1binvoke_container_with_retry\x18h \x01(\x0b\x32=.yandex.cloud.serverless.triggers.v1.InvokeContainerWithRetryH\x00\x42\x0e\n\x06\x61\x63tion\x12\x04\xc0\xc1\x31\x01\x1a\x9e\x03\n\x0cMessageQueue\x12\x16\n\x08queue_id\x18\x0b \x01(\tB\x04\xe8\xc7\x31\x01\x12(\n\x12service_account_id\x18\x03 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12P\n\x0e\x62\x61tch_settings\x18\x04 \x01(\x0b\x32\x32.yandex.cloud.serverless.triggers.v1.BatchSettingsB\x04\xe8\xc7\x31\x01\x12@\n\x12visibility_timeout\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationB\t\xfa\xc7\x31\x05<=12h\x12R\n\x0finvoke_function\x18\x65 \x01(\x0b\x32\x37.yandex.cloud.serverless.triggers.v1.InvokeFunctionOnceH\x00\x12T\n\x10invoke_container\x18\x66 \x01(\x0b\x32\x38.yandex.cloud.serverless.triggers.v1.InvokeContainerOnceH\x00\x42\x0e\n\x06\x61\x63tion\x12\x04\xc0\xc1\x31\x01\x1a\x92\x02\n\nIoTMessage\x12\x19\n\x0bregistry_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x11\n\tdevice_id\x18\x02 \x01(\t\x12\x12\n\nmqtt_topic\x18\x03 \x01(\t\x12W\n\x0finvoke_function\x18\x65 \x01(\x0b\x32<.yandex.cloud.serverless.triggers.v1.InvokeFunctionWithRetryH\x00\x12Y\n\x10invoke_container\x18\x66 \x01(\x0b\x32=.yandex.cloud.serverless.triggers.v1.InvokeContainerWithRetryH\x00\x42\x0e\n\x06\x61\x63tion\x12\x04\xc0\xc1\x31\x01\x1a\x83\x02\n\x10IoTBrokerMessage\x12\x17\n\tbroker_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x12\n\nmqtt_topic\x18\x02 \x01(\t\x12W\n\x0finvoke_function\x18\x65 \x01(\x0b\x32<.yandex.cloud.serverless.triggers.v1.InvokeFunctionWithRetryH\x00\x12Y\n\x10invoke_container\x18\x66 \x01(\x0b\x32=.yandex.cloud.serverless.triggers.v1.InvokeContainerWithRetryH\x00\x42\x0e\n\x06\x61\x63tion\x12\x04\xc0\xc1\x31\x01\x1a\xe7\x02\n\rObjectStorage\x12_\n\nevent_type\x18\x03 \x03(\x0e\x32\x43.yandex.cloud.serverless.triggers.v1.Trigger.ObjectStorageEventTypeB\x06\x82\xc8\x31\x02>0\x12\x11\n\tbucket_id\x18\x04 \x01(\t\x12\x0e\n\x06prefix\x18\x06 \x01(\t\x12\x0e\n\x06suffix\x18\x07 \x01(\t\x12W\n\x0finvoke_function\x18\x65 \x01(\x0b\x32<.yandex.cloud.serverless.triggers.v1.InvokeFunctionWithRetryH\x00\x12Y\n\x10invoke_container\x18\x66 \x01(\x0b\x32=.yandex.cloud.serverless.triggers.v1.InvokeContainerWithRetryH\x00\x42\x0e\n\x06\x61\x63tion\x12\x04\xc0\xc1\x31\x01\x1a\xf2\x02\n\x11\x43ontainerRegistry\x12\x63\n\nevent_type\x18\x03 \x03(\x0e\x32G.yandex.cloud.serverless.triggers.v1.Trigger.ContainerRegistryEventTypeB\x06\x82\xc8\x31\x02>0\x12\x13\n\x0bregistry_id\x18\x04 \x01(\t\x12\x12\n\nimage_name\x18\x05 \x01(\t\x12\x0b\n\x03tag\x18\x06 \x01(\t\x12W\n\x0finvoke_function\x18\x65 \x01(\x0b\x32<.yandex.cloud.serverless.triggers.v1.InvokeFunctionWithRetryH\x00\x12Y\n\x10invoke_container\x18\x66 \x01(\x0b\x32=.yandex.cloud.serverless.triggers.v1.InvokeContainerWithRetryH\x00\x42\x0e\n\x06\x61\x63tion\x12\x04\xc0\xc1\x31\x01\x1a\xc0\x02\n\tCloudLogs\x12\x14\n\x0clog_group_id\x18\x01 \x03(\t\x12Y\n\x0e\x62\x61tch_settings\x18\x02 \x01(\x0b\x32;.yandex.cloud.serverless.triggers.v1.CloudLogsBatchSettingsB\x04\xe8\xc7\x31\x01\x12W\n\x0finvoke_function\x18\x65 \x01(\x0b\x32<.yandex.cloud.serverless.triggers.v1.InvokeFunctionWithRetryH\x00\x12Y\n\x10invoke_container\x18\x66 \x01(\x0b\x32=.yandex.cloud.serverless.triggers.v1.InvokeContainerWithRetryH\x00\x42\x0e\n\x06\x61\x63tion\x12\x04\xc0\xc1\x31\x01\x1a\x8b\x04\n\x07Logging\x12\x1e\n\x0clog_group_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12@\n\rresource_type\x18\x03 \x03(\tB)\xf2\xc7\x31\x1c[a-zA-Z][-a-zA-Z0-9_.]{1,62}\x82\xc8\x31\x05<=100\x12>\n\x0bresource_id\x18\x04 \x03(\tB)\xf2\xc7\x31\x1c[a-zA-Z][-a-zA-Z0-9_.]{1,62}\x82\xc8\x31\x05<=100\x12\x41\n\x06levels\x18\x05 \x03(\x0e\x32\'.yandex.cloud.logging.v1.LogLevel.LevelB\x08\x82\xc8\x31\x04<=10\x12W\n\x0e\x62\x61tch_settings\x18\x06 \x01(\x0b\x32\x39.yandex.cloud.serverless.triggers.v1.LoggingBatchSettingsB\x04\xe8\xc7\x31\x01\x12W\n\x0finvoke_function\x18\x65 \x01(\x0b\x32<.yandex.cloud.serverless.triggers.v1.InvokeFunctionWithRetryH\x00\x12Y\n\x10invoke_container\x18g \x01(\x0b\x32=.yandex.cloud.serverless.triggers.v1.InvokeContainerWithRetryH\x00\x42\x0e\n\x06\x61\x63tion\x12\x04\xc0\xc1\x31\x01\"\xca\x01\n\x16ObjectStorageEventType\x12)\n%OBJECT_STORAGE_EVENT_TYPE_UNSPECIFIED\x10\x00\x12+\n\'OBJECT_STORAGE_EVENT_TYPE_CREATE_OBJECT\x10\x01\x12+\n\'OBJECT_STORAGE_EVENT_TYPE_UPDATE_OBJECT\x10\x02\x12+\n\'OBJECT_STORAGE_EVENT_TYPE_DELETE_OBJECT\x10\x03\"\x93\x02\n\x1a\x43ontainerRegistryEventType\x12-\n)CONTAINER_REGISTRY_EVENT_TYPE_UNSPECIFIED\x10\x00\x12.\n*CONTAINER_REGISTRY_EVENT_TYPE_CREATE_IMAGE\x10\x01\x12.\n*CONTAINER_REGISTRY_EVENT_TYPE_DELETE_IMAGE\x10\x02\x12\x32\n.CONTAINER_REGISTRY_EVENT_TYPE_CREATE_IMAGE_TAG\x10\x03\x12\x32\n.CONTAINER_REGISTRY_EVENT_TYPE_DELETE_IMAGE_TAG\x10\x04\"8\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x01\x12\n\n\x06PAUSED\x10\x02\"i\n\x12InvokeFunctionOnce\x12!\n\x0b\x66unction_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x14\n\x0c\x66unction_tag\x18\x02 \x01(\t\x12\x1a\n\x12service_account_id\x18\x03 \x01(\t\"\x8b\x02\n\x17InvokeFunctionWithRetry\x12!\n\x0b\x66unction_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x14\n\x0c\x66unction_tag\x18\x02 \x01(\t\x12\x1a\n\x12service_account_id\x18\x03 \x01(\t\x12J\n\x0eretry_settings\x18\x04 \x01(\x0b\x32\x32.yandex.cloud.serverless.triggers.v1.RetrySettings\x12O\n\x11\x64\x65\x61\x64_letter_queue\x18\x05 \x01(\x0b\x32\x34.yandex.cloud.serverless.triggers.v1.PutQueueMessage\"c\n\x13InvokeContainerOnce\x12\"\n\x0c\x63ontainer_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x0c\n\x04path\x18\x03 \x01(\t\x12\x1a\n\x12service_account_id\x18\x04 \x01(\t\"\x85\x02\n\x18InvokeContainerWithRetry\x12\"\n\x0c\x63ontainer_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x0c\n\x04path\x18\x03 \x01(\t\x12\x1a\n\x12service_account_id\x18\x04 \x01(\t\x12J\n\x0eretry_settings\x18\x05 \x01(\x0b\x32\x32.yandex.cloud.serverless.triggers.v1.RetrySettings\x12O\n\x11\x64\x65\x61\x64_letter_queue\x18\x06 \x01(\x0b\x32\x34.yandex.cloud.serverless.triggers.v1.PutQueueMessage\"M\n\x0fPutQueueMessage\x12\x10\n\x08queue_id\x18\x0b \x01(\t\x12(\n\x12service_account_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"X\n\rBatchSettings\x12\x16\n\x04size\x18\x01 \x01(\x03\x42\x08\xfa\xc7\x31\x04\x30-10\x12/\n\x06\x63utoff\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x04\xe8\xc7\x31\x01\"g\n\x16\x43loudLogsBatchSettings\x12\x17\n\x04size\x18\x01 \x01(\x03\x42\t\xfa\xc7\x31\x05\x30-100\x12\x34\n\x06\x63utoff\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\t\xfa\xc7\x31\x05\x31s-1m\"e\n\x14LoggingBatchSettings\x12\x17\n\x04size\x18\x01 \x01(\x03\x42\t\xfa\xc7\x31\x05\x31-100\x12\x34\n\x06\x63utoff\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\t\xfa\xc7\x31\x05\x31s-1m\"c\n\rRetrySettings\x12\x1f\n\x0eretry_attempts\x18\x01 \x01(\x03\x42\x07\xfa\xc7\x31\x03\x31-5\x12\x31\n\x08interval\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x04\xe8\xc7\x31\x01\"\x9a\x02\n\rBillingBudget\x12(\n\x12\x62illing_account_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1b\n\tbudget_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12W\n\x0finvoke_function\x18\x65 \x01(\x0b\x32<.yandex.cloud.serverless.triggers.v1.InvokeFunctionWithRetryH\x00\x12Y\n\x10invoke_container\x18g \x01(\x0b\x32=.yandex.cloud.serverless.triggers.v1.InvokeContainerWithRetryH\x00\x42\x0e\n\x06\x61\x63tion\x12\x04\xc0\xc1\x31\x01\"j\n\x17\x44\x61taStreamBatchSettings\x12\x19\n\x04size\x18\x01 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x31-65536\x12\x34\n\x06\x63utoff\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\t\xfa\xc7\x31\x05\x31s-1m\"\xf6\x02\n\nDataStream\x12\x10\n\x08\x65ndpoint\x18\x01 \x01(\t\x12\x10\n\x08\x64\x61tabase\x18\x02 \x01(\t\x12\x0e\n\x06stream\x18\x03 \x01(\t\x12\x1a\n\x12service_account_id\x18\x04 \x01(\t\x12T\n\x0e\x62\x61tch_settings\x18\x05 \x01(\x0b\x32<.yandex.cloud.serverless.triggers.v1.DataStreamBatchSettings\x12W\n\x0finvoke_function\x18\r \x01(\x0b\x32<.yandex.cloud.serverless.triggers.v1.InvokeFunctionWithRetryH\x00\x12Y\n\x10invoke_container\x18\x0f \x01(\x0b\x32=.yandex.cloud.serverless.triggers.v1.InvokeContainerWithRetryH\x00\x42\x0e\n\x06\x61\x63tion\x12\x04\xc0\xc1\x31\x01\"\xd9\x01\n\x04Mail\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12W\n\x0finvoke_function\x18\x65 \x01(\x0b\x32<.yandex.cloud.serverless.triggers.v1.InvokeFunctionWithRetryH\x00\x12Y\n\x10invoke_container\x18g \x01(\x0b\x32=.yandex.cloud.serverless.triggers.v1.InvokeContainerWithRetryH\x00\x42\x0e\n\x06\x61\x63tion\x12\x04\xc0\xc1\x31\x01*\xe2\x01\n\x0bTriggerType\x12\x1c\n\x18TRIGGER_TYPE_UNSPECIFIED\x10\x00\x12\t\n\x05TIMER\x10\x02\x12\x11\n\rMESSAGE_QUEUE\x10\x03\x12\x0f\n\x0bIOT_MESSAGE\x10\x04\x12\x16\n\x12IOT_BROKER_MESSAGE\x10\x0c\x12\x12\n\x0eOBJECT_STORAGE\x10\x05\x12\x16\n\x12\x43ONTAINER_REGISTRY\x10\x06\x12\x0e\n\nCLOUD_LOGS\x10\x07\x12\x0b\n\x07LOGGING\x10\x08\x12\x12\n\x0e\x42ILLING_BUDGET\x10\t\x12\x07\n\x03YDS\x10\n\x12\x08\n\x04MAIL\x10\x0b\x42{\n\'yandex.cloud.api.serverless.triggers.v1ZPgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/triggers/v1;triggersb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,yandex_dot_cloud_dot_logging_dot_v1_dot_log__entry__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])

_TRIGGERTYPE = _descriptor.EnumDescriptor(
  name='TriggerType',
  full_name='yandex.cloud.serverless.triggers.v1.TriggerType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TRIGGER_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TIMER', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MESSAGE_QUEUE', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IOT_MESSAGE', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IOT_BROKER_MESSAGE', index=4, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OBJECT_STORAGE', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONTAINER_REGISTRY', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLOUD_LOGS', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOGGING', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BILLING_BUDGET', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='YDS', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MAIL', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7182,
  serialized_end=7408,
)
_sym_db.RegisterEnumDescriptor(_TRIGGERTYPE)

TriggerType = enum_type_wrapper.EnumTypeWrapper(_TRIGGERTYPE)
TRIGGER_TYPE_UNSPECIFIED = 0
TIMER = 2
MESSAGE_QUEUE = 3
IOT_MESSAGE = 4
IOT_BROKER_MESSAGE = 12
OBJECT_STORAGE = 5
CONTAINER_REGISTRY = 6
CLOUD_LOGS = 7
LOGGING = 8
BILLING_BUDGET = 9
YDS = 10
MAIL = 11


_TRIGGER_OBJECTSTORAGEEVENTTYPE = _descriptor.EnumDescriptor(
  name='ObjectStorageEventType',
  full_name='yandex.cloud.serverless.triggers.v1.Trigger.ObjectStorageEventType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OBJECT_STORAGE_EVENT_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OBJECT_STORAGE_EVENT_TYPE_CREATE_OBJECT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OBJECT_STORAGE_EVENT_TYPE_UPDATE_OBJECT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OBJECT_STORAGE_EVENT_TYPE_DELETE_OBJECT', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4431,
  serialized_end=4633,
)
_sym_db.RegisterEnumDescriptor(_TRIGGER_OBJECTSTORAGEEVENTTYPE)

_TRIGGER_CONTAINERREGISTRYEVENTTYPE = _descriptor.EnumDescriptor(
  name='ContainerRegistryEventType',
  full_name='yandex.cloud.serverless.triggers.v1.Trigger.ContainerRegistryEventType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CONTAINER_REGISTRY_EVENT_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONTAINER_REGISTRY_EVENT_TYPE_CREATE_IMAGE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONTAINER_REGISTRY_EVENT_TYPE_DELETE_IMAGE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONTAINER_REGISTRY_EVENT_TYPE_CREATE_IMAGE_TAG', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONTAINER_REGISTRY_EVENT_TYPE_DELETE_IMAGE_TAG', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4636,
  serialized_end=4911,
)
_sym_db.RegisterEnumDescriptor(_TRIGGER_CONTAINERREGISTRYEVENTTYPE)

_TRIGGER_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='yandex.cloud.serverless.triggers.v1.Trigger.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTIVE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PAUSED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4913,
  serialized_end=4969,
)
_sym_db.RegisterEnumDescriptor(_TRIGGER_STATUS)


_TRIGGER_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.serverless.triggers.v1.Trigger.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.serverless.triggers.v1.Trigger.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.serverless.triggers.v1.Trigger.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=602,
  serialized_end=647,
)

_TRIGGER_RULE = _descriptor.Descriptor(
  name='Rule',
  full_name='yandex.cloud.serverless.triggers.v1.Trigger.Rule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timer', full_name='yandex.cloud.serverless.triggers.v1.Trigger.Rule.timer', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message_queue', full_name='yandex.cloud.serverless.triggers.v1.Trigger.Rule.message_queue', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='iot_message', full_name='yandex.cloud.serverless.triggers.v1.Trigger.Rule.iot_message', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='iot_broker_message', full_name='yandex.cloud.serverless.triggers.v1.Trigger.Rule.iot_broker_message', index=3,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='object_storage', full_name='yandex.cloud.serverless.triggers.v1.Trigger.Rule.object_storage', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='container_registry', full_name='yandex.cloud.serverless.triggers.v1.Trigger.Rule.container_registry', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cloud_logs', full_name='yandex.cloud.serverless.triggers.v1.Trigger.Rule.cloud_logs', index=6,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='logging', full_name='yandex.cloud.serverless.triggers.v1.Trigger.Rule.logging', index=7,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='billing_budget', full_name='yandex.cloud.serverless.triggers.v1.Trigger.Rule.billing_budget', index=8,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_stream', full_name='yandex.cloud.serverless.triggers.v1.Trigger.Rule.data_stream', index=9,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mail', full_name='yandex.cloud.serverless.triggers.v1.Trigger.Rule.mail', index=10,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='rule', full_name='yandex.cloud.serverless.triggers.v1.Trigger.Rule.rule',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=650,
  serialized_end=1536,
)

_TRIGGER_TIMER = _descriptor.Descriptor(
  name='Timer',
  full_name='yandex.cloud.serverless.triggers.v1.Trigger.Timer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cron_expression', full_name='yandex.cloud.serverless.triggers.v1.Trigger.Timer.cron_expression', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='invoke_function', full_name='yandex.cloud.serverless.triggers.v1.Trigger.Timer.invoke_function', index=1,
      number=101, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='invoke_function_with_retry', full_name='yandex.cloud.serverless.triggers.v1.Trigger.Timer.invoke_function_with_retry', index=2,
      number=103, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='invoke_container_with_retry', full_name='yandex.cloud.serverless.triggers.v1.Trigger.Timer.invoke_container_with_retry', index=3,
      number=104, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='action', full_name='yandex.cloud.serverless.triggers.v1.Trigger.Timer.action',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=1539,
  serialized_end=1888,
)

_TRIGGER_MESSAGEQUEUE = _descriptor.Descriptor(
  name='MessageQueue',
  full_name='yandex.cloud.serverless.triggers.v1.Trigger.MessageQueue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='queue_id', full_name='yandex.cloud.serverless.triggers.v1.Trigger.MessageQueue.queue_id', index=0,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_account_id', full_name='yandex.cloud.serverless.triggers.v1.Trigger.MessageQueue.service_account_id', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='batch_settings', full_name='yandex.cloud.serverless.triggers.v1.Trigger.MessageQueue.batch_settings', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='visibility_timeout', full_name='yandex.cloud.serverless.triggers.v1.Trigger.MessageQueue.visibility_timeout', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\005<=12h', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='invoke_function', full_name='yandex.cloud.serverless.triggers.v1.Trigger.MessageQueue.invoke_function', index=4,
      number=101, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='invoke_container', full_name='yandex.cloud.serverless.triggers.v1.Trigger.MessageQueue.invoke_container', index=5,
      number=102, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='action', full_name='yandex.cloud.serverless.triggers.v1.Trigger.MessageQueue.action',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=1891,
  serialized_end=2305,
)

_TRIGGER_IOTMESSAGE = _descriptor.Descriptor(
  name='IoTMessage',
  full_name='yandex.cloud.serverless.triggers.v1.Trigger.IoTMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='registry_id', full_name='yandex.cloud.serverless.triggers.v1.Trigger.IoTMessage.registry_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_id', full_name='yandex.cloud.serverless.triggers.v1.Trigger.IoTMessage.device_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mqtt_topic', full_name='yandex.cloud.serverless.triggers.v1.Trigger.IoTMessage.mqtt_topic', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='invoke_function', full_name='yandex.cloud.serverless.triggers.v1.Trigger.IoTMessage.invoke_function', index=3,
      number=101, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='invoke_container', full_name='yandex.cloud.serverless.triggers.v1.Trigger.IoTMessage.invoke_container', index=4,
      number=102, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='action', full_name='yandex.cloud.serverless.triggers.v1.Trigger.IoTMessage.action',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=2308,
  serialized_end=2582,
)

_TRIGGER_IOTBROKERMESSAGE = _descriptor.Descriptor(
  name='IoTBrokerMessage',
  full_name='yandex.cloud.serverless.triggers.v1.Trigger.IoTBrokerMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broker_id', full_name='yandex.cloud.serverless.triggers.v1.Trigger.IoTBrokerMessage.broker_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mqtt_topic', full_name='yandex.cloud.serverless.triggers.v1.Trigger.IoTBrokerMessage.mqtt_topic', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='invoke_function', full_name='yandex.cloud.serverless.triggers.v1.Trigger.IoTBrokerMessage.invoke_function', index=2,
      number=101, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='invoke_container', full_name='yandex.cloud.serverless.triggers.v1.Trigger.IoTBrokerMessage.invoke_container', index=3,
      number=102, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='action', full_name='yandex.cloud.serverless.triggers.v1.Trigger.IoTBrokerMessage.action',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=2585,
  serialized_end=2844,
)

_TRIGGER_OBJECTSTORAGE = _descriptor.Descriptor(
  name='ObjectStorage',
  full_name='yandex.cloud.serverless.triggers.v1.Trigger.ObjectStorage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_type', full_name='yandex.cloud.serverless.triggers.v1.Trigger.ObjectStorage.event_type', index=0,
      number=3, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bucket_id', full_name='yandex.cloud.serverless.triggers.v1.Trigger.ObjectStorage.bucket_id', index=1,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prefix', full_name='yandex.cloud.serverless.triggers.v1.Trigger.ObjectStorage.prefix', index=2,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='suffix', full_name='yandex.cloud.serverless.triggers.v1.Trigger.ObjectStorage.suffix', index=3,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='invoke_function', full_name='yandex.cloud.serverless.triggers.v1.Trigger.ObjectStorage.invoke_function', index=4,
      number=101, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='invoke_container', full_name='yandex.cloud.serverless.triggers.v1.Trigger.ObjectStorage.invoke_container', index=5,
      number=102, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='action', full_name='yandex.cloud.serverless.triggers.v1.Trigger.ObjectStorage.action',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=2847,
  serialized_end=3206,
)

_TRIGGER_CONTAINERREGISTRY = _descriptor.Descriptor(
  name='ContainerRegistry',
  full_name='yandex.cloud.serverless.triggers.v1.Trigger.ContainerRegistry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_type', full_name='yandex.cloud.serverless.triggers.v1.Trigger.ContainerRegistry.event_type', index=0,
      number=3, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='registry_id', full_name='yandex.cloud.serverless.triggers.v1.Trigger.ContainerRegistry.registry_id', index=1,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_name', full_name='yandex.cloud.serverless.triggers.v1.Trigger.ContainerRegistry.image_name', index=2,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tag', full_name='yandex.cloud.serverless.triggers.v1.Trigger.ContainerRegistry.tag', index=3,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='invoke_function', full_name='yandex.cloud.serverless.triggers.v1.Trigger.ContainerRegistry.invoke_function', index=4,
      number=101, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='invoke_container', full_name='yandex.cloud.serverless.triggers.v1.Trigger.ContainerRegistry.invoke_container', index=5,
      number=102, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='action', full_name='yandex.cloud.serverless.triggers.v1.Trigger.ContainerRegistry.action',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=3209,
  serialized_end=3579,
)

_TRIGGER_CLOUDLOGS = _descriptor.Descriptor(
  name='CloudLogs',
  full_name='yandex.cloud.serverless.triggers.v1.Trigger.CloudLogs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='log_group_id', full_name='yandex.cloud.serverless.triggers.v1.Trigger.CloudLogs.log_group_id', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='batch_settings', full_name='yandex.cloud.serverless.triggers.v1.Trigger.CloudLogs.batch_settings', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='invoke_function', full_name='yandex.cloud.serverless.triggers.v1.Trigger.CloudLogs.invoke_function', index=2,
      number=101, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='invoke_container', full_name='yandex.cloud.serverless.triggers.v1.Trigger.CloudLogs.invoke_container', index=3,
      number=102, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='action', full_name='yandex.cloud.serverless.triggers.v1.Trigger.CloudLogs.action',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=3582,
  serialized_end=3902,
)

_TRIGGER_LOGGING = _descriptor.Descriptor(
  name='Logging',
  full_name='yandex.cloud.serverless.triggers.v1.Trigger.Logging',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='log_group_id', full_name='yandex.cloud.serverless.triggers.v1.Trigger.Logging.log_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_type', full_name='yandex.cloud.serverless.triggers.v1.Trigger.Logging.resource_type', index=1,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\034[a-zA-Z][-a-zA-Z0-9_.]{1,62}\202\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_id', full_name='yandex.cloud.serverless.triggers.v1.Trigger.Logging.resource_id', index=2,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\034[a-zA-Z][-a-zA-Z0-9_.]{1,62}\202\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='levels', full_name='yandex.cloud.serverless.triggers.v1.Trigger.Logging.levels', index=3,
      number=5, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=10', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='batch_settings', full_name='yandex.cloud.serverless.triggers.v1.Trigger.Logging.batch_settings', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='invoke_function', full_name='yandex.cloud.serverless.triggers.v1.Trigger.Logging.invoke_function', index=5,
      number=101, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='invoke_container', full_name='yandex.cloud.serverless.triggers.v1.Trigger.Logging.invoke_container', index=6,
      number=103, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='action', full_name='yandex.cloud.serverless.triggers.v1.Trigger.Logging.action',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=3905,
  serialized_end=4428,
)

_TRIGGER = _descriptor.Descriptor(
  name='Trigger',
  full_name='yandex.cloud.serverless.triggers.v1.Trigger',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.serverless.triggers.v1.Trigger.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.serverless.triggers.v1.Trigger.folder_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='yandex.cloud.serverless.triggers.v1.Trigger.created_at', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.serverless.triggers.v1.Trigger.name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\0043-63', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.serverless.triggers.v1.Trigger.description', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\0050-256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.serverless.triggers.v1.Trigger.labels', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rule', full_name='yandex.cloud.serverless.triggers.v1.Trigger.rule', index=6,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='yandex.cloud.serverless.triggers.v1.Trigger.status', index=7,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TRIGGER_LABELSENTRY, _TRIGGER_RULE, _TRIGGER_TIMER, _TRIGGER_MESSAGEQUEUE, _TRIGGER_IOTMESSAGE, _TRIGGER_IOTBROKERMESSAGE, _TRIGGER_OBJECTSTORAGE, _TRIGGER_CONTAINERREGISTRY, _TRIGGER_CLOUDLOGS, _TRIGGER_LOGGING, ],
  enum_types=[
    _TRIGGER_OBJECTSTORAGEEVENTTYPE,
    _TRIGGER_CONTAINERREGISTRYEVENTTYPE,
    _TRIGGER_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=228,
  serialized_end=4969,
)


_INVOKEFUNCTIONONCE = _descriptor.Descriptor(
  name='InvokeFunctionOnce',
  full_name='yandex.cloud.serverless.triggers.v1.InvokeFunctionOnce',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='function_id', full_name='yandex.cloud.serverless.triggers.v1.InvokeFunctionOnce.function_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='function_tag', full_name='yandex.cloud.serverless.triggers.v1.InvokeFunctionOnce.function_tag', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_account_id', full_name='yandex.cloud.serverless.triggers.v1.InvokeFunctionOnce.service_account_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4971,
  serialized_end=5076,
)


_INVOKEFUNCTIONWITHRETRY = _descriptor.Descriptor(
  name='InvokeFunctionWithRetry',
  full_name='yandex.cloud.serverless.triggers.v1.InvokeFunctionWithRetry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='function_id', full_name='yandex.cloud.serverless.triggers.v1.InvokeFunctionWithRetry.function_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='function_tag', full_name='yandex.cloud.serverless.triggers.v1.InvokeFunctionWithRetry.function_tag', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_account_id', full_name='yandex.cloud.serverless.triggers.v1.InvokeFunctionWithRetry.service_account_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retry_settings', full_name='yandex.cloud.serverless.triggers.v1.InvokeFunctionWithRetry.retry_settings', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dead_letter_queue', full_name='yandex.cloud.serverless.triggers.v1.InvokeFunctionWithRetry.dead_letter_queue', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5079,
  serialized_end=5346,
)


_INVOKECONTAINERONCE = _descriptor.Descriptor(
  name='InvokeContainerOnce',
  full_name='yandex.cloud.serverless.triggers.v1.InvokeContainerOnce',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='container_id', full_name='yandex.cloud.serverless.triggers.v1.InvokeContainerOnce.container_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='yandex.cloud.serverless.triggers.v1.InvokeContainerOnce.path', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_account_id', full_name='yandex.cloud.serverless.triggers.v1.InvokeContainerOnce.service_account_id', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5348,
  serialized_end=5447,
)


_INVOKECONTAINERWITHRETRY = _descriptor.Descriptor(
  name='InvokeContainerWithRetry',
  full_name='yandex.cloud.serverless.triggers.v1.InvokeContainerWithRetry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='container_id', full_name='yandex.cloud.serverless.triggers.v1.InvokeContainerWithRetry.container_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='yandex.cloud.serverless.triggers.v1.InvokeContainerWithRetry.path', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_account_id', full_name='yandex.cloud.serverless.triggers.v1.InvokeContainerWithRetry.service_account_id', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retry_settings', full_name='yandex.cloud.serverless.triggers.v1.InvokeContainerWithRetry.retry_settings', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dead_letter_queue', full_name='yandex.cloud.serverless.triggers.v1.InvokeContainerWithRetry.dead_letter_queue', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5450,
  serialized_end=5711,
)


_PUTQUEUEMESSAGE = _descriptor.Descriptor(
  name='PutQueueMessage',
  full_name='yandex.cloud.serverless.triggers.v1.PutQueueMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='queue_id', full_name='yandex.cloud.serverless.triggers.v1.PutQueueMessage.queue_id', index=0,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_account_id', full_name='yandex.cloud.serverless.triggers.v1.PutQueueMessage.service_account_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5713,
  serialized_end=5790,
)


_BATCHSETTINGS = _descriptor.Descriptor(
  name='BatchSettings',
  full_name='yandex.cloud.serverless.triggers.v1.BatchSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='size', full_name='yandex.cloud.serverless.triggers.v1.BatchSettings.size', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0040-10', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cutoff', full_name='yandex.cloud.serverless.triggers.v1.BatchSettings.cutoff', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5792,
  serialized_end=5880,
)


_CLOUDLOGSBATCHSETTINGS = _descriptor.Descriptor(
  name='CloudLogsBatchSettings',
  full_name='yandex.cloud.serverless.triggers.v1.CloudLogsBatchSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='size', full_name='yandex.cloud.serverless.triggers.v1.CloudLogsBatchSettings.size', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0050-100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cutoff', full_name='yandex.cloud.serverless.triggers.v1.CloudLogsBatchSettings.cutoff', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0051s-1m', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5882,
  serialized_end=5985,
)


_LOGGINGBATCHSETTINGS = _descriptor.Descriptor(
  name='LoggingBatchSettings',
  full_name='yandex.cloud.serverless.triggers.v1.LoggingBatchSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='size', full_name='yandex.cloud.serverless.triggers.v1.LoggingBatchSettings.size', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0051-100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cutoff', full_name='yandex.cloud.serverless.triggers.v1.LoggingBatchSettings.cutoff', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0051s-1m', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5987,
  serialized_end=6088,
)


_RETRYSETTINGS = _descriptor.Descriptor(
  name='RetrySettings',
  full_name='yandex.cloud.serverless.triggers.v1.RetrySettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='retry_attempts', full_name='yandex.cloud.serverless.triggers.v1.RetrySettings.retry_attempts', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0031-5', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interval', full_name='yandex.cloud.serverless.triggers.v1.RetrySettings.interval', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6090,
  serialized_end=6189,
)


_BILLINGBUDGET = _descriptor.Descriptor(
  name='BillingBudget',
  full_name='yandex.cloud.serverless.triggers.v1.BillingBudget',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='billing_account_id', full_name='yandex.cloud.serverless.triggers.v1.BillingBudget.billing_account_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='budget_id', full_name='yandex.cloud.serverless.triggers.v1.BillingBudget.budget_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='invoke_function', full_name='yandex.cloud.serverless.triggers.v1.BillingBudget.invoke_function', index=2,
      number=101, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='invoke_container', full_name='yandex.cloud.serverless.triggers.v1.BillingBudget.invoke_container', index=3,
      number=103, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='action', full_name='yandex.cloud.serverless.triggers.v1.BillingBudget.action',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=6192,
  serialized_end=6474,
)


_DATASTREAMBATCHSETTINGS = _descriptor.Descriptor(
  name='DataStreamBatchSettings',
  full_name='yandex.cloud.serverless.triggers.v1.DataStreamBatchSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='size', full_name='yandex.cloud.serverless.triggers.v1.DataStreamBatchSettings.size', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0071-65536', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cutoff', full_name='yandex.cloud.serverless.triggers.v1.DataStreamBatchSettings.cutoff', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0051s-1m', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6476,
  serialized_end=6582,
)


_DATASTREAM = _descriptor.Descriptor(
  name='DataStream',
  full_name='yandex.cloud.serverless.triggers.v1.DataStream',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='endpoint', full_name='yandex.cloud.serverless.triggers.v1.DataStream.endpoint', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database', full_name='yandex.cloud.serverless.triggers.v1.DataStream.database', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream', full_name='yandex.cloud.serverless.triggers.v1.DataStream.stream', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_account_id', full_name='yandex.cloud.serverless.triggers.v1.DataStream.service_account_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='batch_settings', full_name='yandex.cloud.serverless.triggers.v1.DataStream.batch_settings', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='invoke_function', full_name='yandex.cloud.serverless.triggers.v1.DataStream.invoke_function', index=5,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='invoke_container', full_name='yandex.cloud.serverless.triggers.v1.DataStream.invoke_container', index=6,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='action', full_name='yandex.cloud.serverless.triggers.v1.DataStream.action',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=6585,
  serialized_end=6959,
)


_MAIL = _descriptor.Descriptor(
  name='Mail',
  full_name='yandex.cloud.serverless.triggers.v1.Mail',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='email', full_name='yandex.cloud.serverless.triggers.v1.Mail.email', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='invoke_function', full_name='yandex.cloud.serverless.triggers.v1.Mail.invoke_function', index=1,
      number=101, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='invoke_container', full_name='yandex.cloud.serverless.triggers.v1.Mail.invoke_container', index=2,
      number=103, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='action', full_name='yandex.cloud.serverless.triggers.v1.Mail.action',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=6962,
  serialized_end=7179,
)

_TRIGGER_LABELSENTRY.containing_type = _TRIGGER
_TRIGGER_RULE.fields_by_name['timer'].message_type = _TRIGGER_TIMER
_TRIGGER_RULE.fields_by_name['message_queue'].message_type = _TRIGGER_MESSAGEQUEUE
_TRIGGER_RULE.fields_by_name['iot_message'].message_type = _TRIGGER_IOTMESSAGE
_TRIGGER_RULE.fields_by_name['iot_broker_message'].message_type = _TRIGGER_IOTBROKERMESSAGE
_TRIGGER_RULE.fields_by_name['object_storage'].message_type = _TRIGGER_OBJECTSTORAGE
_TRIGGER_RULE.fields_by_name['container_registry'].message_type = _TRIGGER_CONTAINERREGISTRY
_TRIGGER_RULE.fields_by_name['cloud_logs'].message_type = _TRIGGER_CLOUDLOGS
_TRIGGER_RULE.fields_by_name['logging'].message_type = _TRIGGER_LOGGING
_TRIGGER_RULE.fields_by_name['billing_budget'].message_type = _BILLINGBUDGET
_TRIGGER_RULE.fields_by_name['data_stream'].message_type = _DATASTREAM
_TRIGGER_RULE.fields_by_name['mail'].message_type = _MAIL
_TRIGGER_RULE.containing_type = _TRIGGER
_TRIGGER_RULE.oneofs_by_name['rule'].fields.append(
  _TRIGGER_RULE.fields_by_name['timer'])
_TRIGGER_RULE.fields_by_name['timer'].containing_oneof = _TRIGGER_RULE.oneofs_by_name['rule']
_TRIGGER_RULE.oneofs_by_name['rule'].fields.append(
  _TRIGGER_RULE.fields_by_name['message_queue'])
_TRIGGER_RULE.fields_by_name['message_queue'].containing_oneof = _TRIGGER_RULE.oneofs_by_name['rule']
_TRIGGER_RULE.oneofs_by_name['rule'].fields.append(
  _TRIGGER_RULE.fields_by_name['iot_message'])
_TRIGGER_RULE.fields_by_name['iot_message'].containing_oneof = _TRIGGER_RULE.oneofs_by_name['rule']
_TRIGGER_RULE.oneofs_by_name['rule'].fields.append(
  _TRIGGER_RULE.fields_by_name['iot_broker_message'])
_TRIGGER_RULE.fields_by_name['iot_broker_message'].containing_oneof = _TRIGGER_RULE.oneofs_by_name['rule']
_TRIGGER_RULE.oneofs_by_name['rule'].fields.append(
  _TRIGGER_RULE.fields_by_name['object_storage'])
_TRIGGER_RULE.fields_by_name['object_storage'].containing_oneof = _TRIGGER_RULE.oneofs_by_name['rule']
_TRIGGER_RULE.oneofs_by_name['rule'].fields.append(
  _TRIGGER_RULE.fields_by_name['container_registry'])
_TRIGGER_RULE.fields_by_name['container_registry'].containing_oneof = _TRIGGER_RULE.oneofs_by_name['rule']
_TRIGGER_RULE.oneofs_by_name['rule'].fields.append(
  _TRIGGER_RULE.fields_by_name['cloud_logs'])
_TRIGGER_RULE.fields_by_name['cloud_logs'].containing_oneof = _TRIGGER_RULE.oneofs_by_name['rule']
_TRIGGER_RULE.oneofs_by_name['rule'].fields.append(
  _TRIGGER_RULE.fields_by_name['logging'])
_TRIGGER_RULE.fields_by_name['logging'].containing_oneof = _TRIGGER_RULE.oneofs_by_name['rule']
_TRIGGER_RULE.oneofs_by_name['rule'].fields.append(
  _TRIGGER_RULE.fields_by_name['billing_budget'])
_TRIGGER_RULE.fields_by_name['billing_budget'].containing_oneof = _TRIGGER_RULE.oneofs_by_name['rule']
_TRIGGER_RULE.oneofs_by_name['rule'].fields.append(
  _TRIGGER_RULE.fields_by_name['data_stream'])
_TRIGGER_RULE.fields_by_name['data_stream'].containing_oneof = _TRIGGER_RULE.oneofs_by_name['rule']
_TRIGGER_RULE.oneofs_by_name['rule'].fields.append(
  _TRIGGER_RULE.fields_by_name['mail'])
_TRIGGER_RULE.fields_by_name['mail'].containing_oneof = _TRIGGER_RULE.oneofs_by_name['rule']
_TRIGGER_TIMER.fields_by_name['invoke_function'].message_type = _INVOKEFUNCTIONONCE
_TRIGGER_TIMER.fields_by_name['invoke_function_with_retry'].message_type = _INVOKEFUNCTIONWITHRETRY
_TRIGGER_TIMER.fields_by_name['invoke_container_with_retry'].message_type = _INVOKECONTAINERWITHRETRY
_TRIGGER_TIMER.containing_type = _TRIGGER
_TRIGGER_TIMER.oneofs_by_name['action'].fields.append(
  _TRIGGER_TIMER.fields_by_name['invoke_function'])
_TRIGGER_TIMER.fields_by_name['invoke_function'].containing_oneof = _TRIGGER_TIMER.oneofs_by_name['action']
_TRIGGER_TIMER.oneofs_by_name['action'].fields.append(
  _TRIGGER_TIMER.fields_by_name['invoke_function_with_retry'])
_TRIGGER_TIMER.fields_by_name['invoke_function_with_retry'].containing_oneof = _TRIGGER_TIMER.oneofs_by_name['action']
_TRIGGER_TIMER.oneofs_by_name['action'].fields.append(
  _TRIGGER_TIMER.fields_by_name['invoke_container_with_retry'])
_TRIGGER_TIMER.fields_by_name['invoke_container_with_retry'].containing_oneof = _TRIGGER_TIMER.oneofs_by_name['action']
_TRIGGER_MESSAGEQUEUE.fields_by_name['batch_settings'].message_type = _BATCHSETTINGS
_TRIGGER_MESSAGEQUEUE.fields_by_name['visibility_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_TRIGGER_MESSAGEQUEUE.fields_by_name['invoke_function'].message_type = _INVOKEFUNCTIONONCE
_TRIGGER_MESSAGEQUEUE.fields_by_name['invoke_container'].message_type = _INVOKECONTAINERONCE
_TRIGGER_MESSAGEQUEUE.containing_type = _TRIGGER
_TRIGGER_MESSAGEQUEUE.oneofs_by_name['action'].fields.append(
  _TRIGGER_MESSAGEQUEUE.fields_by_name['invoke_function'])
_TRIGGER_MESSAGEQUEUE.fields_by_name['invoke_function'].containing_oneof = _TRIGGER_MESSAGEQUEUE.oneofs_by_name['action']
_TRIGGER_MESSAGEQUEUE.oneofs_by_name['action'].fields.append(
  _TRIGGER_MESSAGEQUEUE.fields_by_name['invoke_container'])
_TRIGGER_MESSAGEQUEUE.fields_by_name['invoke_container'].containing_oneof = _TRIGGER_MESSAGEQUEUE.oneofs_by_name['action']
_TRIGGER_IOTMESSAGE.fields_by_name['invoke_function'].message_type = _INVOKEFUNCTIONWITHRETRY
_TRIGGER_IOTMESSAGE.fields_by_name['invoke_container'].message_type = _INVOKECONTAINERWITHRETRY
_TRIGGER_IOTMESSAGE.containing_type = _TRIGGER
_TRIGGER_IOTMESSAGE.oneofs_by_name['action'].fields.append(
  _TRIGGER_IOTMESSAGE.fields_by_name['invoke_function'])
_TRIGGER_IOTMESSAGE.fields_by_name['invoke_function'].containing_oneof = _TRIGGER_IOTMESSAGE.oneofs_by_name['action']
_TRIGGER_IOTMESSAGE.oneofs_by_name['action'].fields.append(
  _TRIGGER_IOTMESSAGE.fields_by_name['invoke_container'])
_TRIGGER_IOTMESSAGE.fields_by_name['invoke_container'].containing_oneof = _TRIGGER_IOTMESSAGE.oneofs_by_name['action']
_TRIGGER_IOTBROKERMESSAGE.fields_by_name['invoke_function'].message_type = _INVOKEFUNCTIONWITHRETRY
_TRIGGER_IOTBROKERMESSAGE.fields_by_name['invoke_container'].message_type = _INVOKECONTAINERWITHRETRY
_TRIGGER_IOTBROKERMESSAGE.containing_type = _TRIGGER
_TRIGGER_IOTBROKERMESSAGE.oneofs_by_name['action'].fields.append(
  _TRIGGER_IOTBROKERMESSAGE.fields_by_name['invoke_function'])
_TRIGGER_IOTBROKERMESSAGE.fields_by_name['invoke_function'].containing_oneof = _TRIGGER_IOTBROKERMESSAGE.oneofs_by_name['action']
_TRIGGER_IOTBROKERMESSAGE.oneofs_by_name['action'].fields.append(
  _TRIGGER_IOTBROKERMESSAGE.fields_by_name['invoke_container'])
_TRIGGER_IOTBROKERMESSAGE.fields_by_name['invoke_container'].containing_oneof = _TRIGGER_IOTBROKERMESSAGE.oneofs_by_name['action']
_TRIGGER_OBJECTSTORAGE.fields_by_name['event_type'].enum_type = _TRIGGER_OBJECTSTORAGEEVENTTYPE
_TRIGGER_OBJECTSTORAGE.fields_by_name['invoke_function'].message_type = _INVOKEFUNCTIONWITHRETRY
_TRIGGER_OBJECTSTORAGE.fields_by_name['invoke_container'].message_type = _INVOKECONTAINERWITHRETRY
_TRIGGER_OBJECTSTORAGE.containing_type = _TRIGGER
_TRIGGER_OBJECTSTORAGE.oneofs_by_name['action'].fields.append(
  _TRIGGER_OBJECTSTORAGE.fields_by_name['invoke_function'])
_TRIGGER_OBJECTSTORAGE.fields_by_name['invoke_function'].containing_oneof = _TRIGGER_OBJECTSTORAGE.oneofs_by_name['action']
_TRIGGER_OBJECTSTORAGE.oneofs_by_name['action'].fields.append(
  _TRIGGER_OBJECTSTORAGE.fields_by_name['invoke_container'])
_TRIGGER_OBJECTSTORAGE.fields_by_name['invoke_container'].containing_oneof = _TRIGGER_OBJECTSTORAGE.oneofs_by_name['action']
_TRIGGER_CONTAINERREGISTRY.fields_by_name['event_type'].enum_type = _TRIGGER_CONTAINERREGISTRYEVENTTYPE
_TRIGGER_CONTAINERREGISTRY.fields_by_name['invoke_function'].message_type = _INVOKEFUNCTIONWITHRETRY
_TRIGGER_CONTAINERREGISTRY.fields_by_name['invoke_container'].message_type = _INVOKECONTAINERWITHRETRY
_TRIGGER_CONTAINERREGISTRY.containing_type = _TRIGGER
_TRIGGER_CONTAINERREGISTRY.oneofs_by_name['action'].fields.append(
  _TRIGGER_CONTAINERREGISTRY.fields_by_name['invoke_function'])
_TRIGGER_CONTAINERREGISTRY.fields_by_name['invoke_function'].containing_oneof = _TRIGGER_CONTAINERREGISTRY.oneofs_by_name['action']
_TRIGGER_CONTAINERREGISTRY.oneofs_by_name['action'].fields.append(
  _TRIGGER_CONTAINERREGISTRY.fields_by_name['invoke_container'])
_TRIGGER_CONTAINERREGISTRY.fields_by_name['invoke_container'].containing_oneof = _TRIGGER_CONTAINERREGISTRY.oneofs_by_name['action']
_TRIGGER_CLOUDLOGS.fields_by_name['batch_settings'].message_type = _CLOUDLOGSBATCHSETTINGS
_TRIGGER_CLOUDLOGS.fields_by_name['invoke_function'].message_type = _INVOKEFUNCTIONWITHRETRY
_TRIGGER_CLOUDLOGS.fields_by_name['invoke_container'].message_type = _INVOKECONTAINERWITHRETRY
_TRIGGER_CLOUDLOGS.containing_type = _TRIGGER
_TRIGGER_CLOUDLOGS.oneofs_by_name['action'].fields.append(
  _TRIGGER_CLOUDLOGS.fields_by_name['invoke_function'])
_TRIGGER_CLOUDLOGS.fields_by_name['invoke_function'].containing_oneof = _TRIGGER_CLOUDLOGS.oneofs_by_name['action']
_TRIGGER_CLOUDLOGS.oneofs_by_name['action'].fields.append(
  _TRIGGER_CLOUDLOGS.fields_by_name['invoke_container'])
_TRIGGER_CLOUDLOGS.fields_by_name['invoke_container'].containing_oneof = _TRIGGER_CLOUDLOGS.oneofs_by_name['action']
_TRIGGER_LOGGING.fields_by_name['levels'].enum_type = yandex_dot_cloud_dot_logging_dot_v1_dot_log__entry__pb2._LOGLEVEL_LEVEL
_TRIGGER_LOGGING.fields_by_name['batch_settings'].message_type = _LOGGINGBATCHSETTINGS
_TRIGGER_LOGGING.fields_by_name['invoke_function'].message_type = _INVOKEFUNCTIONWITHRETRY
_TRIGGER_LOGGING.fields_by_name['invoke_container'].message_type = _INVOKECONTAINERWITHRETRY
_TRIGGER_LOGGING.containing_type = _TRIGGER
_TRIGGER_LOGGING.oneofs_by_name['action'].fields.append(
  _TRIGGER_LOGGING.fields_by_name['invoke_function'])
_TRIGGER_LOGGING.fields_by_name['invoke_function'].containing_oneof = _TRIGGER_LOGGING.oneofs_by_name['action']
_TRIGGER_LOGGING.oneofs_by_name['action'].fields.append(
  _TRIGGER_LOGGING.fields_by_name['invoke_container'])
_TRIGGER_LOGGING.fields_by_name['invoke_container'].containing_oneof = _TRIGGER_LOGGING.oneofs_by_name['action']
_TRIGGER.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TRIGGER.fields_by_name['labels'].message_type = _TRIGGER_LABELSENTRY
_TRIGGER.fields_by_name['rule'].message_type = _TRIGGER_RULE
_TRIGGER.fields_by_name['status'].enum_type = _TRIGGER_STATUS
_TRIGGER_OBJECTSTORAGEEVENTTYPE.containing_type = _TRIGGER
_TRIGGER_CONTAINERREGISTRYEVENTTYPE.containing_type = _TRIGGER
_TRIGGER_STATUS.containing_type = _TRIGGER
_INVOKEFUNCTIONWITHRETRY.fields_by_name['retry_settings'].message_type = _RETRYSETTINGS
_INVOKEFUNCTIONWITHRETRY.fields_by_name['dead_letter_queue'].message_type = _PUTQUEUEMESSAGE
_INVOKECONTAINERWITHRETRY.fields_by_name['retry_settings'].message_type = _RETRYSETTINGS
_INVOKECONTAINERWITHRETRY.fields_by_name['dead_letter_queue'].message_type = _PUTQUEUEMESSAGE
_BATCHSETTINGS.fields_by_name['cutoff'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_CLOUDLOGSBATCHSETTINGS.fields_by_name['cutoff'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_LOGGINGBATCHSETTINGS.fields_by_name['cutoff'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_RETRYSETTINGS.fields_by_name['interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_BILLINGBUDGET.fields_by_name['invoke_function'].message_type = _INVOKEFUNCTIONWITHRETRY
_BILLINGBUDGET.fields_by_name['invoke_container'].message_type = _INVOKECONTAINERWITHRETRY
_BILLINGBUDGET.oneofs_by_name['action'].fields.append(
  _BILLINGBUDGET.fields_by_name['invoke_function'])
_BILLINGBUDGET.fields_by_name['invoke_function'].containing_oneof = _BILLINGBUDGET.oneofs_by_name['action']
_BILLINGBUDGET.oneofs_by_name['action'].fields.append(
  _BILLINGBUDGET.fields_by_name['invoke_container'])
_BILLINGBUDGET.fields_by_name['invoke_container'].containing_oneof = _BILLINGBUDGET.oneofs_by_name['action']
_DATASTREAMBATCHSETTINGS.fields_by_name['cutoff'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_DATASTREAM.fields_by_name['batch_settings'].message_type = _DATASTREAMBATCHSETTINGS
_DATASTREAM.fields_by_name['invoke_function'].message_type = _INVOKEFUNCTIONWITHRETRY
_DATASTREAM.fields_by_name['invoke_container'].message_type = _INVOKECONTAINERWITHRETRY
_DATASTREAM.oneofs_by_name['action'].fields.append(
  _DATASTREAM.fields_by_name['invoke_function'])
_DATASTREAM.fields_by_name['invoke_function'].containing_oneof = _DATASTREAM.oneofs_by_name['action']
_DATASTREAM.oneofs_by_name['action'].fields.append(
  _DATASTREAM.fields_by_name['invoke_container'])
_DATASTREAM.fields_by_name['invoke_container'].containing_oneof = _DATASTREAM.oneofs_by_name['action']
_MAIL.fields_by_name['invoke_function'].message_type = _INVOKEFUNCTIONWITHRETRY
_MAIL.fields_by_name['invoke_container'].message_type = _INVOKECONTAINERWITHRETRY
_MAIL.oneofs_by_name['action'].fields.append(
  _MAIL.fields_by_name['invoke_function'])
_MAIL.fields_by_name['invoke_function'].containing_oneof = _MAIL.oneofs_by_name['action']
_MAIL.oneofs_by_name['action'].fields.append(
  _MAIL.fields_by_name['invoke_container'])
_MAIL.fields_by_name['invoke_container'].containing_oneof = _MAIL.oneofs_by_name['action']
DESCRIPTOR.message_types_by_name['Trigger'] = _TRIGGER
DESCRIPTOR.message_types_by_name['InvokeFunctionOnce'] = _INVOKEFUNCTIONONCE
DESCRIPTOR.message_types_by_name['InvokeFunctionWithRetry'] = _INVOKEFUNCTIONWITHRETRY
DESCRIPTOR.message_types_by_name['InvokeContainerOnce'] = _INVOKECONTAINERONCE
DESCRIPTOR.message_types_by_name['InvokeContainerWithRetry'] = _INVOKECONTAINERWITHRETRY
DESCRIPTOR.message_types_by_name['PutQueueMessage'] = _PUTQUEUEMESSAGE
DESCRIPTOR.message_types_by_name['BatchSettings'] = _BATCHSETTINGS
DESCRIPTOR.message_types_by_name['CloudLogsBatchSettings'] = _CLOUDLOGSBATCHSETTINGS
DESCRIPTOR.message_types_by_name['LoggingBatchSettings'] = _LOGGINGBATCHSETTINGS
DESCRIPTOR.message_types_by_name['RetrySettings'] = _RETRYSETTINGS
DESCRIPTOR.message_types_by_name['BillingBudget'] = _BILLINGBUDGET
DESCRIPTOR.message_types_by_name['DataStreamBatchSettings'] = _DATASTREAMBATCHSETTINGS
DESCRIPTOR.message_types_by_name['DataStream'] = _DATASTREAM
DESCRIPTOR.message_types_by_name['Mail'] = _MAIL
DESCRIPTOR.enum_types_by_name['TriggerType'] = _TRIGGERTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Trigger = _reflection.GeneratedProtocolMessageType('Trigger', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _TRIGGER_LABELSENTRY,
    '__module__' : 'yandex.cloud.serverless.triggers.v1.trigger_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.triggers.v1.Trigger.LabelsEntry)
    })
  ,

  'Rule' : _reflection.GeneratedProtocolMessageType('Rule', (_message.Message,), {
    'DESCRIPTOR' : _TRIGGER_RULE,
    '__module__' : 'yandex.cloud.serverless.triggers.v1.trigger_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.triggers.v1.Trigger.Rule)
    })
  ,

  'Timer' : _reflection.GeneratedProtocolMessageType('Timer', (_message.Message,), {
    'DESCRIPTOR' : _TRIGGER_TIMER,
    '__module__' : 'yandex.cloud.serverless.triggers.v1.trigger_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.triggers.v1.Trigger.Timer)
    })
  ,

  'MessageQueue' : _reflection.GeneratedProtocolMessageType('MessageQueue', (_message.Message,), {
    'DESCRIPTOR' : _TRIGGER_MESSAGEQUEUE,
    '__module__' : 'yandex.cloud.serverless.triggers.v1.trigger_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.triggers.v1.Trigger.MessageQueue)
    })
  ,

  'IoTMessage' : _reflection.GeneratedProtocolMessageType('IoTMessage', (_message.Message,), {
    'DESCRIPTOR' : _TRIGGER_IOTMESSAGE,
    '__module__' : 'yandex.cloud.serverless.triggers.v1.trigger_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.triggers.v1.Trigger.IoTMessage)
    })
  ,

  'IoTBrokerMessage' : _reflection.GeneratedProtocolMessageType('IoTBrokerMessage', (_message.Message,), {
    'DESCRIPTOR' : _TRIGGER_IOTBROKERMESSAGE,
    '__module__' : 'yandex.cloud.serverless.triggers.v1.trigger_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.triggers.v1.Trigger.IoTBrokerMessage)
    })
  ,

  'ObjectStorage' : _reflection.GeneratedProtocolMessageType('ObjectStorage', (_message.Message,), {
    'DESCRIPTOR' : _TRIGGER_OBJECTSTORAGE,
    '__module__' : 'yandex.cloud.serverless.triggers.v1.trigger_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.triggers.v1.Trigger.ObjectStorage)
    })
  ,

  'ContainerRegistry' : _reflection.GeneratedProtocolMessageType('ContainerRegistry', (_message.Message,), {
    'DESCRIPTOR' : _TRIGGER_CONTAINERREGISTRY,
    '__module__' : 'yandex.cloud.serverless.triggers.v1.trigger_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.triggers.v1.Trigger.ContainerRegistry)
    })
  ,

  'CloudLogs' : _reflection.GeneratedProtocolMessageType('CloudLogs', (_message.Message,), {
    'DESCRIPTOR' : _TRIGGER_CLOUDLOGS,
    '__module__' : 'yandex.cloud.serverless.triggers.v1.trigger_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.triggers.v1.Trigger.CloudLogs)
    })
  ,

  'Logging' : _reflection.GeneratedProtocolMessageType('Logging', (_message.Message,), {
    'DESCRIPTOR' : _TRIGGER_LOGGING,
    '__module__' : 'yandex.cloud.serverless.triggers.v1.trigger_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.triggers.v1.Trigger.Logging)
    })
  ,
  'DESCRIPTOR' : _TRIGGER,
  '__module__' : 'yandex.cloud.serverless.triggers.v1.trigger_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.triggers.v1.Trigger)
  })
_sym_db.RegisterMessage(Trigger)
_sym_db.RegisterMessage(Trigger.LabelsEntry)
_sym_db.RegisterMessage(Trigger.Rule)
_sym_db.RegisterMessage(Trigger.Timer)
_sym_db.RegisterMessage(Trigger.MessageQueue)
_sym_db.RegisterMessage(Trigger.IoTMessage)
_sym_db.RegisterMessage(Trigger.IoTBrokerMessage)
_sym_db.RegisterMessage(Trigger.ObjectStorage)
_sym_db.RegisterMessage(Trigger.ContainerRegistry)
_sym_db.RegisterMessage(Trigger.CloudLogs)
_sym_db.RegisterMessage(Trigger.Logging)

InvokeFunctionOnce = _reflection.GeneratedProtocolMessageType('InvokeFunctionOnce', (_message.Message,), {
  'DESCRIPTOR' : _INVOKEFUNCTIONONCE,
  '__module__' : 'yandex.cloud.serverless.triggers.v1.trigger_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.triggers.v1.InvokeFunctionOnce)
  })
_sym_db.RegisterMessage(InvokeFunctionOnce)

InvokeFunctionWithRetry = _reflection.GeneratedProtocolMessageType('InvokeFunctionWithRetry', (_message.Message,), {
  'DESCRIPTOR' : _INVOKEFUNCTIONWITHRETRY,
  '__module__' : 'yandex.cloud.serverless.triggers.v1.trigger_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.triggers.v1.InvokeFunctionWithRetry)
  })
_sym_db.RegisterMessage(InvokeFunctionWithRetry)

InvokeContainerOnce = _reflection.GeneratedProtocolMessageType('InvokeContainerOnce', (_message.Message,), {
  'DESCRIPTOR' : _INVOKECONTAINERONCE,
  '__module__' : 'yandex.cloud.serverless.triggers.v1.trigger_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.triggers.v1.InvokeContainerOnce)
  })
_sym_db.RegisterMessage(InvokeContainerOnce)

InvokeContainerWithRetry = _reflection.GeneratedProtocolMessageType('InvokeContainerWithRetry', (_message.Message,), {
  'DESCRIPTOR' : _INVOKECONTAINERWITHRETRY,
  '__module__' : 'yandex.cloud.serverless.triggers.v1.trigger_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.triggers.v1.InvokeContainerWithRetry)
  })
_sym_db.RegisterMessage(InvokeContainerWithRetry)

PutQueueMessage = _reflection.GeneratedProtocolMessageType('PutQueueMessage', (_message.Message,), {
  'DESCRIPTOR' : _PUTQUEUEMESSAGE,
  '__module__' : 'yandex.cloud.serverless.triggers.v1.trigger_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.triggers.v1.PutQueueMessage)
  })
_sym_db.RegisterMessage(PutQueueMessage)

BatchSettings = _reflection.GeneratedProtocolMessageType('BatchSettings', (_message.Message,), {
  'DESCRIPTOR' : _BATCHSETTINGS,
  '__module__' : 'yandex.cloud.serverless.triggers.v1.trigger_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.triggers.v1.BatchSettings)
  })
_sym_db.RegisterMessage(BatchSettings)

CloudLogsBatchSettings = _reflection.GeneratedProtocolMessageType('CloudLogsBatchSettings', (_message.Message,), {
  'DESCRIPTOR' : _CLOUDLOGSBATCHSETTINGS,
  '__module__' : 'yandex.cloud.serverless.triggers.v1.trigger_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.triggers.v1.CloudLogsBatchSettings)
  })
_sym_db.RegisterMessage(CloudLogsBatchSettings)

LoggingBatchSettings = _reflection.GeneratedProtocolMessageType('LoggingBatchSettings', (_message.Message,), {
  'DESCRIPTOR' : _LOGGINGBATCHSETTINGS,
  '__module__' : 'yandex.cloud.serverless.triggers.v1.trigger_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.triggers.v1.LoggingBatchSettings)
  })
_sym_db.RegisterMessage(LoggingBatchSettings)

RetrySettings = _reflection.GeneratedProtocolMessageType('RetrySettings', (_message.Message,), {
  'DESCRIPTOR' : _RETRYSETTINGS,
  '__module__' : 'yandex.cloud.serverless.triggers.v1.trigger_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.triggers.v1.RetrySettings)
  })
_sym_db.RegisterMessage(RetrySettings)

BillingBudget = _reflection.GeneratedProtocolMessageType('BillingBudget', (_message.Message,), {
  'DESCRIPTOR' : _BILLINGBUDGET,
  '__module__' : 'yandex.cloud.serverless.triggers.v1.trigger_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.triggers.v1.BillingBudget)
  })
_sym_db.RegisterMessage(BillingBudget)

DataStreamBatchSettings = _reflection.GeneratedProtocolMessageType('DataStreamBatchSettings', (_message.Message,), {
  'DESCRIPTOR' : _DATASTREAMBATCHSETTINGS,
  '__module__' : 'yandex.cloud.serverless.triggers.v1.trigger_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.triggers.v1.DataStreamBatchSettings)
  })
_sym_db.RegisterMessage(DataStreamBatchSettings)

DataStream = _reflection.GeneratedProtocolMessageType('DataStream', (_message.Message,), {
  'DESCRIPTOR' : _DATASTREAM,
  '__module__' : 'yandex.cloud.serverless.triggers.v1.trigger_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.triggers.v1.DataStream)
  })
_sym_db.RegisterMessage(DataStream)

Mail = _reflection.GeneratedProtocolMessageType('Mail', (_message.Message,), {
  'DESCRIPTOR' : _MAIL,
  '__module__' : 'yandex.cloud.serverless.triggers.v1.trigger_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.triggers.v1.Mail)
  })
_sym_db.RegisterMessage(Mail)


DESCRIPTOR._options = None
_TRIGGER_LABELSENTRY._options = None
_TRIGGER_RULE.oneofs_by_name['rule']._options = None
_TRIGGER_TIMER.oneofs_by_name['action']._options = None
_TRIGGER_TIMER.fields_by_name['cron_expression']._options = None
_TRIGGER_MESSAGEQUEUE.oneofs_by_name['action']._options = None
_TRIGGER_MESSAGEQUEUE.fields_by_name['queue_id']._options = None
_TRIGGER_MESSAGEQUEUE.fields_by_name['service_account_id']._options = None
_TRIGGER_MESSAGEQUEUE.fields_by_name['batch_settings']._options = None
_TRIGGER_MESSAGEQUEUE.fields_by_name['visibility_timeout']._options = None
_TRIGGER_IOTMESSAGE.oneofs_by_name['action']._options = None
_TRIGGER_IOTMESSAGE.fields_by_name['registry_id']._options = None
_TRIGGER_IOTBROKERMESSAGE.oneofs_by_name['action']._options = None
_TRIGGER_IOTBROKERMESSAGE.fields_by_name['broker_id']._options = None
_TRIGGER_OBJECTSTORAGE.oneofs_by_name['action']._options = None
_TRIGGER_OBJECTSTORAGE.fields_by_name['event_type']._options = None
_TRIGGER_CONTAINERREGISTRY.oneofs_by_name['action']._options = None
_TRIGGER_CONTAINERREGISTRY.fields_by_name['event_type']._options = None
_TRIGGER_CLOUDLOGS.oneofs_by_name['action']._options = None
_TRIGGER_CLOUDLOGS.fields_by_name['batch_settings']._options = None
_TRIGGER_LOGGING.oneofs_by_name['action']._options = None
_TRIGGER_LOGGING.fields_by_name['log_group_id']._options = None
_TRIGGER_LOGGING.fields_by_name['resource_type']._options = None
_TRIGGER_LOGGING.fields_by_name['resource_id']._options = None
_TRIGGER_LOGGING.fields_by_name['levels']._options = None
_TRIGGER_LOGGING.fields_by_name['batch_settings']._options = None
_TRIGGER.fields_by_name['folder_id']._options = None
_TRIGGER.fields_by_name['name']._options = None
_TRIGGER.fields_by_name['description']._options = None
_TRIGGER.fields_by_name['rule']._options = None
_INVOKEFUNCTIONONCE.fields_by_name['function_id']._options = None
_INVOKEFUNCTIONWITHRETRY.fields_by_name['function_id']._options = None
_INVOKECONTAINERONCE.fields_by_name['container_id']._options = None
_INVOKECONTAINERWITHRETRY.fields_by_name['container_id']._options = None
_PUTQUEUEMESSAGE.fields_by_name['service_account_id']._options = None
_BATCHSETTINGS.fields_by_name['size']._options = None
_BATCHSETTINGS.fields_by_name['cutoff']._options = None
_CLOUDLOGSBATCHSETTINGS.fields_by_name['size']._options = None
_CLOUDLOGSBATCHSETTINGS.fields_by_name['cutoff']._options = None
_LOGGINGBATCHSETTINGS.fields_by_name['size']._options = None
_LOGGINGBATCHSETTINGS.fields_by_name['cutoff']._options = None
_RETRYSETTINGS.fields_by_name['retry_attempts']._options = None
_RETRYSETTINGS.fields_by_name['interval']._options = None
_BILLINGBUDGET.oneofs_by_name['action']._options = None
_BILLINGBUDGET.fields_by_name['billing_account_id']._options = None
_BILLINGBUDGET.fields_by_name['budget_id']._options = None
_DATASTREAMBATCHSETTINGS.fields_by_name['size']._options = None
_DATASTREAMBATCHSETTINGS.fields_by_name['cutoff']._options = None
_DATASTREAM.oneofs_by_name['action']._options = None
_MAIL.oneofs_by_name['action']._options = None
# @@protoc_insertion_point(module_scope)
